#
# spec file for package perl-Date-Calc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Date-Calc
Name:           perl-Date-Calc
Version:        6.400.0
Release:        1.3
# 6.4 -> normalize -> 6.400.0
%define cpan_version 6.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Gregorian calendar date calculations
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/ST/STBEY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         fix2038.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Bit::Vector) >= 7.400
BuildRequires:  perl(Carp::Clan) >= 6.40.0
Requires:       perl(Bit::Vector) >= 7.400
Requires:       perl(Carp::Clan) >= 6.40.0
Provides:       perl(Date::Calc) = %{version}
Provides:       perl(Date::Calc::Object) = %{version}
Provides:       perl(Date::Calc::PP) = %{version}
Provides:       perl(Date::Calendar) = %{version}
Provides:       perl(Date::Calendar::Profiles) = %{version}
Provides:       perl(Date::Calendar::Year) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Date::Calc::XS) >= 6.400
%{perl_requires}

%description
  * 'use Date::Calc qw( Days_in_Year Days_in_Month ... );'

  * 'use Date::Calc qw(:all);'

You can either specify the functions you want to import explicitly by
enumerating them between the parentheses of the "'qw()'" operator, or you
can use the "':all'" tag instead to import *ALL* available functions.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES.txt CREDITS.txt README.txt
%license license

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Mar 17 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add fix2038.patch to handle dates beyond year 2038
* Thu Apr 16 2015 coolo@suse.com
- updated to 6.4
  see /usr/share/doc/packages/perl-Date-Calc/CHANGES.txt
- remove upstream Date-Calc-6.3.diff
* Sun Jan  4 2015 coolo@suse.com
- Date::Calc's parse logic puts 3.1.64 into 2064 if it's closer to
  $NOW than 1964, which is the case since 1.1.2015
  updated Date-Calc-6.3.diff for
  https://rt.cpan.org/Public/Bug/Display.html?id=101232
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Feb 26 2010 anicka@suse.cz
- update to 6.3
  * The language can now be set individually for each function
    in "Date::Calc" that requires it (through a new optional
    parameter; the default continues to be a global setting
    for backward compatibility); the affected functions are:
    "Decode_Month()", "Decode_Day_of_Week()", "Compressed_to_Text()",
    "Date_to_Text()", "Date_to_Text_Long()", "Calendar()",
    "Month_to_Text()", "Day_of_Week_to_Text()", "Day_of_Week_Abbreviation()",
    "Decode_Date_EU()", "Decode_Date_US()", "Decode_Date_EU2()",
    "Decode_Date_US2()", "Parse_Date()".
  * BEWARE that the interface of "DateCalc.c" has changed!
  * Module "Date::Calc::Object" has been changed similarly
  * Module "Date::Calendar::Year" has also been adapted accordingly
  * bugfixes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 5.6
  * Made the module MacOS X compatible
  * Made some tiny changes to the documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 cthiel@suse.de
- added perl-Carp-Clan to neededforbuild
* Mon Aug  1 2005 cthiel@suse.de
- update to version 5.4
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon May 26 2003 mjancar@suse.cz
- remove Carp::Clan conflicting with perl-Bit-Vector
* Thu May 22 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
- use #!/usr/bin/perl instead of #!perl in examples
- package omited man page
- dont package MANIFEST
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Thu Dec 19 2002 prehak@suse.cz
- updated to version 5.3
- added doc files, adjusted their permissions
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 22 2002 rvasice@suse.cz
- update to version 5.0
- actualize filelist
- use macros %%{perl_sitearch}, %%{perl_archlib}, %%{_prefix}
- added make test
* Mon Nov  6 2000 grimmer@suse.de
- renamed from perl_dc to perl-Date-Calc
- update to Version 4.3
- spec file cleanups (macros, BuildRoot)
* Fri Jan 21 2000 ro@suse.de
- fixed filelist
* Thu Oct 28 1999 tmg@suse.de
- created package (Date-Calc-4.2)
